[master 13/26] Fix missed rebase of populator test from 169dc6b6.

vathpela installerbot-noreply at redhat.com
Fri Nov 6 18:31:16 UTC 2015


From: David Lehman <dlehman at redhat.com>

---
 tests/populator_test.py | 21 +++++++++++----------
 1 file changed, 11 insertions(+), 10 deletions(-)

diff --git a/tests/populator_test.py b/tests/populator_test.py
index 7cd7f74..9e36cc6 100644
--- a/tests/populator_test.py
+++ b/tests/populator_test.py
@@ -4,13 +4,14 @@
 from blivet.flags import flags
 from blivet import util
 from blivet.size import Size
-from blivet.osinstall import storageInitialize
+from blivet.osinstall import storage_initialize
 try:
     from pyanaconda import kickstart
     pyanaconda_present = True
 except ImportError:
     pyanaconda_present = False
 
+
 @unittest.skipUnless(pyanaconda_present, "pyanaconda is missing")
 class setupDiskImagesNonZeroSizeTestCase(unittest.TestCase):
     """
@@ -18,7 +19,7 @@ class setupDiskImagesNonZeroSizeTestCase(unittest.TestCase):
         This test emulates how anaconda configures its storage.
     """
 
-    disks = { "disk1": Size("2 GiB") }
+    disks = {"disk1": Size("2 GiB")}
 
     def setUp(self):
         self.blivet = Blivet()
@@ -26,26 +27,26 @@ def setUp(self):
         # anaconda first configures disk images
         for (name, size) in iter(self.disks.items()):
             path = util.create_sparse_tempfile(name, size)
-            self.blivet.config.diskImages[name] = path
+            self.blivet.config.disk_images[name] = path
 
         # at this point the DMLinearDevice has correct size
-        self.blivet.setupDiskImages()
+        self.blivet.setup_disk_images()
 
         # emulates setting the anaconda flags which later update
         # blivet flags as the first thing to do in storageInitialize
         flags.image_install = True
         # no kickstart available
         ksdata = kickstart.AnacondaKSHandler([])
         # anaconda calls storageInitialize regardless of whether or not
         # this is an image install. Somewhere along the line this will
         # execute setupDiskImages() once more and the DMLinearDevice created
         # in this second execution has size 0
-        storageInitialize(self.blivet, ksdata, [])
+        storage_initialize(self.blivet, ksdata, [])
 
     def tearDown(self):
         self.blivet.reset()
-        self.blivet.devicetree.teardownDiskImages()
-        for fn in self.blivet.config.diskImages.values():
+        self.blivet.devicetree.teardown_disk_images()
+        for fn in self.blivet.config.disk_images.values():
             if os.path.exists(fn):
                 os.unlink(fn)
 
@@ -26,26 +27,26 @@ def setUp(self):
 
         # emulates setting the anaconda flags which later update
-        # blivet flags as the first thing to do in storageInitialize
+        # blivet flags as the first thing to do in storage_initialize
         flags.image_install = True
         # no kickstart available
@@ -26,26 +27,26 @@ def setUp(self):
         # no kickstart available
         ksdata = kickstart.AnacondaKSHandler([])
-        # anaconda calls storageInitialize regardless of whether or not
+        # anaconda calls storage_initialize regardless of whether or not
         # this is an image install. Somewhere along the line this will
@@ -26,26 +27,26 @@ def setUp(self):
         # this is an image install. Somewhere along the line this will
-        # execute setupDiskImages() once more and the DMLinearDevice created
+        # execute setup_disk_images() once more and the DMLinearDevice created
         # in this second execution has size 0


-- 
To view this commit on github, visit https://github.com/rhinstaller/blivet/commit/8e8f37b90088d8df6c3a65cee4efdfc8d50fd69a


More information about the anaconda-patches mailing list